@@ -26,6 +26,7 @@ use constant {
     ARRAY           => 'ARRAY',
     HASH            => 'HASH',
     CODE            => 'CODE',
+    GLOB            => 'GLOB',
     REGEX           => 'Regexp',
     
     # constant values
@@ -59,7 +60,7 @@ CONSTANTS->export_any(qw(
 
 CONSTANTS->export_tags({
     types => [qw( 
-        SCALAR ARRAY HASH CODE REGEX
+        SCALAR ARRAY HASH CODE GLOB REGEX
     )],
     values => [qw(
         FALSE TRUE OFF ON ALL NONE DEFAULT
@@ -135,6 +136,14 @@ The literal word C<CODE>, typically used for testing references.
         ...
     }
 
+=head2 GLOB
+
+The literal word C<GLOB>, typically used for testing references.
+
+    if (ref $data eq GLOB) {
+        ...
+    }
+
 =head2 REGEX
 
 The literal word C<Regexp>, typically used for testing references.
